@@ -23,14 +23,18 @@
 #include "utils/algos.h"
 #include "postmaster/bgworker.h"
 #include "catalog/pg_sequence.h"
+
 typedef struct PGPROC PGPROC;
-extern bool replaying_ddl_log;
-extern char *remote_stmt_ptr;
 
 extern Oid find_root_base_type(Oid typid0);
 extern void update_colnames_indices(Relation attrelation, Relation targetrelation,
 	int attnum, const char *oldattname, const char *newattname);
+
 extern const char* atsubcmd(AlterTableCmd *subcmd);
+
 extern void build_column_data_type(StringInfo str, Oid typid,
-       int32 typmod, Oid collation);
+	int32 typmod, Oid collation);
+
+extern bool front_end_is_mysql();
+
 #endif /* !REMOTE_META_H */
