@@ -18,6 +18,7 @@
 #include "access/heapam.h"
 #include "access/tupconvert.h"
 #include "executor/instrument.h"
+#include "executor/remoteTupleCache.h"
 #include "lib/pairingheap.h"
 #include "nodes/params.h"
 #include "nodes/plannodes.h"
@@ -501,6 +502,9 @@ typedef struct ResultRelInfo
 	 * sqls to update/delete tuples one by one.
 	 */
 	struct RemoteModifyTupleCommon *ri_RemoteModifyTupleCommon;
+
+	/* On conflict clause */
+	StringInfo ri_remoteOnconflict;
 } ResultRelInfo;
 
 
@@ -720,6 +724,7 @@ typedef struct TupleHashTableData
 	AttrNumber *keyColIdx;		/* attr numbers of key columns */
 	FmgrInfo   *tab_hash_funcs; /* hash functions for table datatype(s) */
 	ExprState  *tab_eq_func;	/* comparator for table datatype(s) */
+	Oid		   *tab_collations;
 	MemoryContext tablecxt;		/* memory context containing table */
 	MemoryContext tempcxt;		/* context for function evaluations */
 	Size		entrysize;		/* actual size to make each hash entry */
@@ -891,6 +896,7 @@ typedef struct SubPlanState
 									 * datatype(s) */
 	FmgrInfo   *tab_hash_funcs; /* hash functions for table datatype(s) */
 	FmgrInfo   *tab_eq_funcs;	/* equality functions for table datatype(s) */
+	Oid		   *tab_collations;
 	FmgrInfo   *lhs_hash_funcs; /* hash functions for lefthand datatype(s) */
 	FmgrInfo   *cur_eq_funcs;	/* equality functions for LHS vs. table */
 	ExprState  *cur_eq_comp;	/* equality comparator for LHS vs. table */
@@ -930,6 +936,22 @@ typedef struct DomainConstraintState
 	ExprState  *check_exprstate;	/* check_expr's eval state, or NULL */
 } DomainConstraintState;
 
+/* 
+ * 用于实现Batched Nestloop
+ */
+#define MEMOIZE_TUPLE_SIZE 128
+typedef struct MemoizeTuples
+{
+	MemoryContext context;
+	TupleTableSlot *current_slot;
+	TupleTableSlot *slot;
+	List *nestParams;
+	MinimalTuple mintuple[MEMOIZE_TUPLE_SIZE];
+	int ntuples;	/* 有效元组*/
+	int current;
+	bool completed;
+	int gen;
+} MemoizeTuples;
 
 /* ----------------------------------------------------------------
  *				 Executor State Trees
@@ -966,7 +988,8 @@ typedef struct PlanState
 								 * nodes point to one EState for the whole
 								 * top-level plan */
 
-	ExecProcNodeMtd ExecProcNode;	/* function to return next tuple */
+	ExecProcNodeMtd PreExecProcNode;	/* dispensable function before ExecProcNode */
+	ExecProcNodeMtd ExecProcNode;		/* function to return next tuple */
 	ExecProcNodeMtd ExecProcNodeReal;	/* actual function, if above is a
 										 * wrapper */
 
@@ -994,6 +1017,11 @@ typedef struct PlanState
 	 */
 	Bitmapset  *chgParam;		/* set of IDs of changed Params */
 
+	/*
+	 * Cached tuples from outer plan in nestloop join
+	 */
+	MemoizeTuples *bnl_outer_tuples;
+
 	/*
 	 * Other run-time state needed by most if not all node types.
 	 */
@@ -1277,19 +1305,14 @@ typedef struct ScanState
 	TupleTableSlot *ss_ScanTupleSlot;
 } ScanState;
 
-struct SortColRef;
+struct ParallelRemotePlanDesc;
 
-/*
- * The table name conflict when generating remote sql
- */
-struct RangeTblEntry;
-typedef struct TableNameConflict
+enum RemoteTupleCacheState
 {
-	int relid;
-	char *name;			/* The orignal name of the conflict table */
-	char *newName;		/* The modified name of the conflict table */
-	struct RangeTblEntry *rte;
-} TableNameConflict;
+	LOOKUP_ENTRY = 0,
+	ENTRY_NEXT_TUPLE,
+	ENTRY_END
+};
 
 typedef struct RemotePlanState
 {
@@ -1324,6 +1347,23 @@ typedef struct RemotePlanState
 	  of a join. If so store result rather than use result.
 	*/
 	bool will_rewind;
+
+	bool partialscan;
+	List *partialscan_ranges;
+	struct ParallelRemotePlanDesc *p_desc;
+
+	/* 
+	  Recover table migration errors by waiting and retrying.
+	 */
+	bool can_recovery_table_migration;
+	int table_migration_recovery_retries;
+
+	/* Tuple cache used in BNL */
+	int bnl_outer_tuples_gen;
+	StringInfoData extern_param_digest;
+	enum RemoteTupleCacheState cache_state;
+	RemoteTupleCache *cache;
+	RemoteTupleCacheEntry *entry;
 } RemotePlanState;
 
 /* ----------------
@@ -1836,6 +1876,7 @@ typedef struct NestLoopState
 	bool		nl_NeedNewOuter;
 	bool		nl_MatchedOuter;
 	TupleTableSlot *nl_NullInnerTupleSlot;
+	MemoizeTuples *memoize_tuples;
 } NestLoopState;
 
 /* ----------------
@@ -1923,6 +1964,7 @@ typedef struct HashJoinState
 	List	   *hj_OuterHashKeys;	/* list of ExprState nodes */
 	List	   *hj_InnerHashKeys;	/* list of ExprState nodes */
 	List	   *hj_HashOperators;	/* list of operator OIDs */
+	List	   *hj_Collations;
 	HashJoinTable hj_HashTable;
 	uint32		hj_CurHashValue;
 	int			hj_CurBucketNo;
