@@ -21,7 +21,6 @@
 #include "nodes/bitmapset.h"
 #include "nodes/pg_list.h"
 
-
 /* ----------------------------------------------------------------
  *						node definitions
  * ----------------------------------------------------------------
@@ -112,6 +111,7 @@ typedef struct IntoClause
 	RangeVar   *rel;			/* target relation name */
 	List	   *colNames;		/* column names to assign, or NIL */
 	List	   *options;		/* options from WITH clause */
+	int			options_location;
 	OnCommitAction onCommit;	/* what do we do at COMMIT? */
 	char	   *tableSpaceName; /* table space to use, or NULL */
 	Node	   *viewQuery;		/* materialized view's SELECT query */
@@ -156,7 +156,8 @@ typedef struct Expr
 #define    INNER_VAR		65000	/* reference to inner subplan */
 #define    OUTER_VAR		65001	/* reference to outer subplan */
 #define    INDEX_VAR		65002	/* reference to index column */
-#define    REMOTE_VAR       65003   /* reference to remote scan tuple */
+#define	   REMOTE_VAR		65003	/* reference to remote scan tuple */
+#define	   MERGEAGG_VAR		65004
 
 #define IS_SPECIAL_VARNO(varno)		((varno) >= INNER_VAR)
 
@@ -1369,7 +1370,7 @@ typedef struct InferenceElem
  * DISTINCT items.  Targetlist entries with ressortgroupref=0 are not
  * sort/group items.  If ressortgroupref>0, then this item is an ORDER BY,
  * GROUP BY, and/or DISTINCT target value.  No two entries in a targetlist
- * may have the same nonzero ressortgroupref --- but there is no particular
+ * may have the same nonzero ressortgroupref, but there is no particular
  * meaning to the nonzero values, except as tags.  (For example, one must
  * not assume that lower ressortgroupref means a more significant sort key.)
  * The order of the associated SortGroupClause lists determine the semantics.
@@ -1477,6 +1478,7 @@ typedef struct JoinExpr
 	Node	   *quals;			/* qualifiers on join, if any */
 	Alias	   *alias;			/* user-written alias clause, if any */
 	int			rtindex;		/* RT index assigned for join, or 0 */
+	bool		fake_right_deep;
 } JoinExpr;
 
 /*----------
