@@ -55,6 +55,7 @@ enum SysCacheIdentifier
 	CONNAMENSP,
 	CONSTROID,
 	CONVOID,
+	DATABASENAMEMAP,
 	DATABASEOID,
 	DEFACLROLENSPOBJ,
 	ENUMOID,
@@ -104,6 +105,8 @@ enum SysCacheIdentifier
 	SUBSCRIPTIONOID,
 	SUBSCRIPTIONRELMAP,
 	TABLESPACEOID,
+	TABLEGROUPOID,
+	TABLEGROUPNAME,
 	TRFOID,
 	TRFTYPELANG,
 	TSCONFIGMAP,
