@@ -45,6 +45,21 @@ def init_db(args):
   initcmd = cmd0 + localied_work_dir + '/bin/initdb -D ' + localied_data_dir + ' 2>&1'
   os.system(initcmd) 
 
+def open_single_shard_mode(localied_conf_path):
+  new_content = ""
+  with open(localied_conf_path, 'r') as f:
+    for line in f:
+      if line.startswith('single_shard_mode'):
+        new_content = new_content + 'single_shard_mode = true\n'
+      else:
+        new_content = new_content + line;
+    
+    f.close()
+  
+  with open(localied_conf_path, 'w') as f:
+    f.write(new_content)
+    f.close()
+
 def deal_conf(args):
   global localied_conf_path
   global localied_data_dir
@@ -64,6 +79,10 @@ def deal_conf(args):
   conf_file = open(localied_conf_path,'w')
   conf_file.write(conf_content)
   conf_file.close()
+  
+  if args.single_shard_mode == 'on':
+    open_single_shard_mode(localied_conf_path)
+
   os.system('echo "host all all ' + args.bind_address + '/32 trust" >> ' + localied_data_dir + '/pg_hba.conf')
   os.system('echo "host all all 127.0.0.1/32  trust" >> ' + localied_data_dir + '/pg_hba.conf')
   os.system('echo "host all agent 0.0.0.0/0 reject" >> ' + localied_data_dir + '/pg_hba.conf')
@@ -182,6 +201,7 @@ if __name__ == "__main__":
   parser.add_argument('--datadir_prefix',type=str,help="Postgres data dir prefix",required=True)
   parser.add_argument('--install_prefix',type=str,help="Postgres install prefix",required=True)
   parser.add_argument('--prog_name',type=str,help="Postgres pkg name",required=True)
+  parser.add_argument('--single_shard_mode',type=str,help="Postgres single shard mode",required=True)
   parser.add_argument('--valgrind',type=bool,help="Start Postgresql with valgrind or not",required=False,default=False)
   args= parser.parse_args()
 
